@@ -120,6 +120,7 @@ class MythbuntuReposPlugin(MCCPlugin):
             self.hseparator5.hide()
             self.footer_alignment.hide()
             self.trunk_block.hide()
+            self.DOWNLOADURL = 'http://people.ubuntu.com/~tgm4883/repos.db'
             
         self.changes = {}
         self.repobox.get_model().clear()
@@ -225,7 +226,7 @@ class MythbuntuReposPlugin(MCCPlugin):
         try:
           url = self.DOWNLOADURL
         except:
-          url = 'http://download.mythbuntu.org/repos/repos.db'
+          url = 'http://people.ubuntu.com/~tgm4883/repos.db'
         try:
             import urllib.request
             from urllib.error import HTTPError,URLError
